@@ -338,9 +338,12 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 				
 	/* HIG defaults */
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 2); /* 2 * 5 + 2 = 12 */
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+			     2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+					5);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
+			     6);
 
 	file = gedit_dirs_get_ui_file ("gedit-search-dialog.ui");
 	ret = gedit_utils_get_ui_objects (file,
@@ -361,7 +364,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	{
 		gtk_widget_show (error_widget);
 
-		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+		gtk_box_pack_start_defaults (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 					     error_widget);
 		gtk_container_set_border_width (GTK_CONTAINER (error_widget),
 						5);
@@ -439,7 +442,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 					   GEDIT_SEARCH_DIALOG_REPLACE_ALL_RESPONSE,
 					   FALSE);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			    content, FALSE, FALSE, 0);
 	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);
